@@ -2,19 +2,25 @@
 
 class SettingsAPI:
 
-    def __init__(self, settings_path):
-        self.SETTINGSPATH = settings_path
-        self.SETTINGS = self.LoadSettings()
-        self.VERSION = self.SETTINGS.get("version") if self.SETTINGS.get("version") else None
-        self.LANGUAGE = self.SETTINGS.get("language") if self.SETTINGS.get("language") else None
-        self.PACKAGEPATH = self.SETTINGS.get("packagepath") if self.SETTINGS.get("packagepath") else None
-        self.CACHEPATH = self.SETTINGS.get("cachepath") if self.SETTINGS.get("cachepath") else None
-        self.TEMPPATH = self.SETTINGS.get("temppath") if self.SETTINGS.get("temppath") else None
-        self.LOGPATH = self.SETTINGS.get("logpath") if self.SETTINGS.get("logpath") else None
-        self.APIPATH = self.SETTINGS.get("apipath") if self.SETTINGS.get("apipath") else None
-        self.LANGUAGEPATH = self.SETTINGS.get("languagepath") if self.SETTINGS.get("languagepath") else None
-        self.MODPATH = self.SETTINGS.get("modpath") if self.SETTINGS.get("modpath") else None
-        self.MODS_ENABLED = self.SETTINGS.get("mods_enabled") if self.SETTINGS.get ("mods_enabled") else False
+    def __init__(self, app):
+        self.app = app
+        try:
+            self.SETTINGSPATH = self.app.SDK.SDK_SETTINGS
+            self.SETTINGS = self.LoadSettings()
+            self.VERSION = self.SETTINGS.get("version") if self.SETTINGS.get("version") else None
+            self.LANGUAGE = self.SETTINGS.get("language") if self.SETTINGS.get("language") else None
+            self.PACKAGEPATH = self.SETTINGS.get("packagepath") if self.SETTINGS.get("packagepath") else None
+            self.CACHEPATH = self.SETTINGS.get("cachepath") if self.SETTINGS.get("cachepath") else None
+            self.TEMPPATH = self.SETTINGS.get("temppath") if self.SETTINGS.get("temppath") else None
+            self.LOGPATH = self.SETTINGS.get("logpath") if self.SETTINGS.get("logpath") else None
+            self.APIPATH = self.SETTINGS.get("apipath") if self.SETTINGS.get("apipath") else None
+            self.LANGUAGEPATH = self.SETTINGS.get("languagepath") if self.SETTINGS.get("languagepath") else None
+            self.MODPATH = self.SETTINGS.get("modpath") if self.SETTINGS.get("modpath") else None
+            self.MODS_ENABLED = self.SETTINGS.get("mods_enabled") if self.SETTINGS.get ("mods_enabled") else False
+        except Exception:
+            import os
+            current_dir = os.path.dirname(os.path.abspath(__file__))
+            settings_path = os.path.join(current_dir, self.app.SDK.SDK_SETTINGS)
 
     def LoadSettings(self):
         import json
@@ -60,16 +66,12 @@ class StateMachineAPI:
     EXIT = "exit"
     MAINMENU = "main_menu"
     FIRST_ENTRY = "first_entry"
-    ERROR = "error"
     
     
     
     def __init__(self):
         """beginning with first_entry state"""
         self.state = self.FIRST_ENTRY
-        self.state_data = {}
-        
-        self.IsRunning = True
         
     def SetState(self, new_state):
         self.state = new_state
@@ -80,16 +82,6 @@ class StateMachineAPI:
     def IsState(self, check_state):
         return self.state == check_state
     
-    def Stop(self, should_exit=True):
-        self.IsRunning = False
-        if should_exit:
-            exit(0)
-            
-    def SetKeyState(self, key, default_value=False):
-        self.state_data[key] = default_value
-
-    def GetKeyState(self, key):
-        return self.state_data.get(key, False)
 
     #? ################  CACHE API #####################
 
@@ -245,8 +237,8 @@ class LogAPI:
 
 class ManagerAPI:
     
-    def __init__(self, api_path):
-        self.API_PATH = api_path
+    def __init__(self):
+        pass
         
         
         
@@ -254,14 +246,6 @@ class ManagerAPI:
     
 class GuiAPI:
     
-    def __init__(self):
-        pass
-    
-    
-    #? ################  UTILS API #####################
-    
-class UtilsAPI:
-    
     def __init__(self):
         pass
         
@@ -269,17 +253,30 @@ class UtilsAPI:
 
 class HelperAPI:
     
-    def __init__(self, settings):
-        self.Settings = settings
-        self.Gui = GuiAPI()
+    def __init__(self, app):
+        self.app = app
+        self.ui = GuiAPI()
+        self.command = CommandAPI(app)
 
     def GetVersion(self):
-        return self.Settings.VERSION
+        return self.app.Settings.VERSION
 
     def GetLanguage(self):
-        return self.Settings.LANGUAGE
+        return self.app.Settings.LANGUAGE
     
-    #? ################  LANGUAGE API #####################
+    
+
+class CommandAPI:
+
+    def __init__(self, app):
+        self.app = app
+        
+    def Execute(self, command):
+        import subprocess
+        result = subprocess.run(command, shell=True, capture_output=True, text=True)
+        return result.stdout, result.stderr, result.returncode
+
+    #? ################  LANGUAGE API #################
 
 class LanguageAPI:
 
@@ -336,10 +333,8 @@ class LanguageAPI:
         """Translating Keyword by key with current language-data"""
         return self.language_data.get(key, key)
     
-    def GetAllTranslationKeys(self, lang=None):
+    def GetAllTranslationKeys(self):
         """Returning all translation keys"""
-        if lang:
-            return list(self.LoadLanguageData(lang).keys())
         return list(self.language_data.keys())
     
     def GetAvailableLanguages(self):
@@ -361,23 +356,19 @@ class LanguageAPI:
 
 class ToolAPI:
     
-    def __init__(self, settings_path, **sdk):
+    def __init__(self, **sdk):
         """Requires sdk{version, name}. Build for ToolOS"""
-        self.SDK = sdk
-        self.SDK_VERSION = sdk.get("version")
-        self.SDK_NAME = sdk.get("name")
-        self.SDK_LangLib = sdk.get("standard_language_library")
-        self.Settings = SettingsAPI(settings_path)
-        if self.CheckCompatibility(self.Settings.VERSION, self.SDK_VERSION):
+        self.SDK = SDK(**sdk)
+        self.Settings = SettingsAPI(self)
+        if self.CheckCompatibility(self.Settings.VERSION, self.SDK.SDK_VERSION):
             self.Cache = CacheAPI(self.Settings.CACHEPATH)
             self.Temp = TempAPI(self.Settings.TEMPPATH)
             self.Package = PackageAPI(self.Settings.PACKAGEPATH)
             self.Log = LogAPI(self.Settings.LOGPATH)
-            self.manager = ManagerAPI(self.Settings.APIPATH)
-            self.helper = HelperAPI(self.Settings)
-            self.language = LanguageAPI(self.Settings, standard_library=self.SDK_LangLib)
+            self.manager = ManagerAPI()
+            self.helper = HelperAPI(self)
+            self.language = LanguageAPI(self.Settings, standard_library=self.SDK.SDK_LangLib)
             self.state_machine = StateMachineAPI()
-            self.Utils = UtilsAPI()
 
     def CheckCompatibility(self, api_version, sdk_version: str):
         major, minor, patch = sdk_version.split(".")
@@ -388,15 +379,26 @@ class ToolAPI:
     #? ################  Global API #####################
     
 class Api:
-    def __init__(self, settings_path="settings.json", standard_language_library=True):
+    def __init__(self, **sdk):
         """ToolAPI's API-SDK. made for general use."""
-        self.Settings = SettingsAPI(settings_path)
+        self.SDK = SDK(**sdk)
+        self.Settings = SettingsAPI(self.SDK.SDK_SETTINGS)
         self.Cache = CacheAPI(self.Settings.CACHEPATH)
         self.Temp = TempAPI(self.Settings.TEMPPATH)
         self.Package = PackageAPI(self.Settings.PACKAGEPATH)
         self.Log = LogAPI(self.Settings.LOGPATH)
-        self.Manager = ManagerAPI(self.Settings.APIPATH)
+        self.Manager = ManagerAPI()
         self.Helper = HelperAPI(self.Settings)
-        self.Language = LanguageAPI(self.Settings, standard_library=standard_language_library)
+        self.Language = LanguageAPI(self.Settings, standard_library=self.SDK.SDK_LangLib)
         self.StateMachine = StateMachineAPI()
-        self.Utils = UtilsAPI()
+        
+        
+class SDK:
+    
+    def __init__(self, **sdk):
+        """ToolAPI's SDK. made for developers."""
+        self.SDK = sdk
+        self.SDK_VERSION = sdk.get("version")
+        self.SDK_SETTINGS = sdk.get("settings_path")
+        self.SDK_NAME = sdk.get("name")
+        self.SDK_LangLib = sdk.get("standard_language_library")
